¡Bienvenido a la documentación de pydatajson!
=============================================

.. toctree::
   :maxdepth: 2

   README.md
   MANUAL.md
   HISTORY.md

Indices y tablas
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
